﻿*************************************************************************************************************************.

* Data without Boundaries - DwB.
* Training Course on EU-LFS.
* 17th to 19th September 2014, Ljubljana.

* Practical Computing Session II.

* EU-LFS Training Dataset.
* based on EU-LFS 2012, yearly data, integrated file of all countries.
* subsample of about 5000 cases per country.
* 21 countries: AT, BE, CH, CZ, DE, EE, ES, FR, GR, HU, IE, IT, LT, LU, NL, RO, SI, SK, PL, PT, UK.

* Andrea Lengerer, GESIS - Leibniz Institute for the Social Sciences.

*************************************************************************************************************************.


* Exercise 2: Analyses on the household level and on the couple level.


*************************************************************************************************************************.






*-----------------------------------------------------------   Preparation   -----------------------------------------------------------.

* specify the path where the EU-LFS training dataset is stored.
FILE HANDLE data_path / NAME='...'.

* specify the path where you want to save your data.
FILE HANDLE mydata_path / NAME='...'.



* open the EU-LFS training dataset.
GET FILE='data_path/LFS_2012y_td.sav'.

* exclude Switzerland (no household information available).
SELECT IF country NE 4.
EXECUTE.

* selection of population living in private households.
SELECT IF hhpriv=1.
EXECUTE.

* check: 100 214 cases in total.
FREQ country.


* structure of the data - core household information.
* LIST VAR=country qhhnum hhseqnum age sex hhlink hhspou hhfath hhmoth / CASES=FROM 1 TO 30.






*-------------------------   Exercise 2a: Presence, number and age of children in the household   -------------------------.


*--- Step 1: Identification of children ---.

* a person is considered a child if
  - the person is less than 15 years old
  - the person is between 15 and 19 years old, lives with at least one parent in the household (hhfath, hhmoth)
    and is economically inactive (ilostat).

* required variables.
FREQ age hhfath hhmoth ilostat.

* create auxiliary variable "child" with value 1 for each child and with value 0 for all other persons.
COMPUTE child=0.
IF age<=12 OR (age=17 AND (hhfath>=1 OR hhmoth>=1) AND ilostat=3) child=1.
EXECUTE.

* check.
FREQ child.
LIST VAR=country qhhnum hhseqnum age hhfath hhmoth ilostat child / CASES=FROM 1 TO 20.



*--- Step 2: Count the number of children in the household ---.

* calculate the sum of the values of the variable "child" on the household level, as indicated by qhhnum
  (note, that not only the variable qhhnum is necessary to identify households, but also country - because
  it could be the case that households from different countries have the same value of qhhnum).
SORT CASES BY country qhhnum.
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK country qhhnum
   / sum_child=SUM(child).
EXECUTE.

* more than 2 children in one category.
RECODE sum_child (3 THRU HI=3) (ELSE=COPY).
EXECUTE.
VARIABLE LABELS sum_child 'number of children in the household'.
VALUE LABELS sum_child
   0 'no children'
   1 '1 child'
   2 '2 children'
   3 '3 or more children'.

* check.
FREQ sum_child.
LIST VAR=country qhhnum hhseqnum age hhfath hhmoth child sum_child / CASES=FROM 1 TO 20.



*--- Step 3: Calculate the proportion of households in each country by number of children (select the
     reference person in the household to ensure that each household counts only once) ---.

TEMPORARY.
SELECT IF hhlink=1.
CROSSTABS country BY sum_child / CELLS=ROW / BARCHART.



*--- Step 4: Calculate the age of the youngest child in the household ---.

* create variable "childage" with the age of each respective child and with system missing for
  all other persons.
IF child=1 childage=age.
EXECUTE.

* check.
FREQ childage.
LIST VAR=country qhhnum hhseqnum age hhfath hhmoth child childage / CASES=FROM 1 TO 20.

* calculate the minimum of the values of the variable "childage" on the household level (as indicated by qhhnum).
AGGREGATE OUTFILE=* MODE=ADDVARIABLES
   / PRESORTED
   / BREAK country qhhnum
   / min_childage=MIN(childage).
EXECUTE.

* age categories: <5, 5-9, 10-19, no child <20.
* note: system missing of min_childage implies that there is no child <20 in the household.
RECODE min_childage (2=2) (7=7) (12 THRU 17=15) (SYSMIS=0).
EXECUTE.
VARIABLE LABELS min_childage 'age of youngest child in the household'.
VALUE LABELS min_childage
   0 'no child <20'
   2 '0-4 years of age'
   7 '5-9 years of age'
   15 '10-19 years of age'.

* check.
FREQ min_childage.
LIST VAR=country qhhnum hhseqnum age hhfath hhmoth child childage min_childage / CASES=FROM 1 TO 20.



*--- Step 5: Calculate the proportion of households in each country by age of the youngest child
     (select the reference person in the household to ensure that each household counts only once) ---.

TEMPORARY.
SELECT IF hhlink=1.
CROSSTABS country BY min_childage / CELLS=ROW.



*--- save file ---.

SAVE OUTFILE='mydata_path/data_ex2a.sav'.






*-------------------------------------   Exercise 2b: Employment patterns of couples   --------------------------------------.

GET  FILE='mydata_path/data_ex2a.sav'.

* in order to simplify the exercise, we ignore that there are same-sex couples.



*--- Step 1: Combine the information on the employment status of both partners in one row of the dataset ---.

* check.
LIST VAR=country qhhnum hhseqnum sex age hhspou ilostat ftpt / CASES=FROM 1 TO 20.


* select partnered women (hhspou>0) and save them in a separate file.
* rename hhspou in hhseqnum (for the subsequent merging - since hhspou corresponds to hhseqnum of the partner).
* keep and rename other needed variables.
* sort the data in a suitable way (the latter merging requires equal sorting of both files).
SORT CASES BY country qhhnum hhspou.
TEMPORARY.
SELECT IF sex=2 AND hhspou>0.
SAVE OUTFILE='mydata_path/part_w.sav'
   / KEEP=country qhhnum hhspou age ilostat ftpt hatlev1d
   / RENAME (hhspou age ilostat ftpt hatlev1d=hhseqnum age_w ilostat_w ftpt_w hatlev1d_w).


* merge the initial file (as master file) with the separate file of partnered women (as slave file) by hhseqnum.
SORT CASES BY country qhhnum hhseqnum.
MATCH FILES / FILE=*
   / TABLES='mydata_path/part_w.sav'
   / BY country qhhnum hhseqnum.
EXECUTE.


* check.
LIST VAR=country qhhnum hhseqnum sex age hhspou ilostat ftpt age_w ilostat_w ftpt_w
   / CASES=FROM 1 TO 20.



*--- Step 2: Classify the employment patterns ---.

* employment patterns:
  (1) traditional breadwinner model: single-earner, man full-time, woman inactive
  (2) modified breadwinner model: dual-earner, man full-time, woman part-time
  (3) egalitarian model: dual-earner, both full-time
  (4) other.

* required variables.
FREQ ilostat ftpt.

* couples only.
DO IF age_w>=1.
   IF ilostat=1 AND ftpt=1 AND ilostat_w=3 empat=1.
   IF ilostat=1 AND ftpt=1 AND ilostat_w=1 AND ftpt_w=2 empat=2.
   IF ilostat=1 AND ftpt=1 AND ilostat_w=1 AND ftpt_w=1 empat=3.
   IF (ilostat=2 OR ilostat=3) OR ftpt=2 OR ilostat_w=2 empat=4.
END IF.
EXECUTE.

* note: couples who can't be classified remain on system missing.

VARIABLE LABELS empat 'employment pattern of couples'.
VALUE LABELS empat
   1 'traditional breadwinner model'
   2 'modified breadwinner model'
   3 'egalitarian model'
   4 'other'.


* check.
FREQ empat.
LIST VAR=country qhhnum hhseqnum sex age hhspou ilostat ftpt age_w ilostat_w ftpt_w empat
   / CASES=FROM 1 TO 40.



*--- Step 3: Calculate the prevalence of the different employment patterns of couples,
     depending on the age of the youngest child in the household, by country ---.

* couples, women aged 25 to 54.
TEMP.
SELECT IF age_w>=27 AND age_w<=52.
CROSSTABS empat BY min_childage BY country / CELLS=COL.



*--- save file ---.

SAVE OUTFILE='mydata_path/data_ex2b.sav'.






*--------------------------   Exercise 2c: Determinants of the employment patterns of couples   --------------------------.

GET FILE='mydata_path/data_ex2b.sav'.


*--- Step 1: Selection of couples where the women are aged 25 to 54 ---.

SELECT IF age_w>=27 AND age_w<=52.
EXECUTE.


* check: 14 892 couples.
FREQ empat.
LIST VAR=country qhhnum hhseqnum sex age hatlev1d age_w hatlev1d_w empat min_childage
   / CASES=FROM 1 TO 20.



*--- Step 2: Prepare independent variables ---.

* age of the youngest child in the household (min_childage).
* level of education of both partners (hatlev1d, hatlev1d_w).
* country (country).

FREQ min_childage hatlev1d hatlev1d_w country.


* reference categories:
  - age of the youngest child in the household: no child <20 (min_childage=0))
  - level of education of both partners: high (hatlev1d=3, hatlev1d_w=3)
  - country: UK (country=31).

* as default SPSS uses the last category as reference category.

* necessary recoding.
RECODE min_childage (0=99) (ELSE=COPY).
VALUE LABELS min_childage
   2 '0-4 years of age'
   7 '5-9 years of age'
   15 '10-19 years of age'
   99 'no child <20'.

* check.
FREQ min_childage.



*-- Step 3: Run a multinomial logistic regression model for employment patterns of couples ---.

* use the traditional breadwinner model as reference category (empat=1).
* include main effects for
  - age of the youngest child in the household (min_childage, reference category: no child <20)
  - level of education of both partners (hatlev1d and hatlev1d_w, reference category: high).
* control for country (country, reference category: UK).
* save predicted probabilities.


NOMREG empat (BASE=FIRST ORDER=ASCENDING) BY min_childage hatlev1d hatlev1d_w country
   /MODEL
   /INTERCEPT=INCLUDE
   /PRINT=LRT KERNEL CPS PARAMETER SUMMARY MFI
   /SAVE ESTPROB.


* predicted probabilities.
VARIABLE LABELS  est1_1 'pred prob traditional'.
VARIABLE LABELS  est2_1 'pred prob modified'.
VARIABLE LABELS  est3_1 'pred prob egalitarian'.
VARIABLE LABELS  est4_1 'pred prob other'.


* check.
LIST VAR=country qhhnum hhseqnum sex age hatlev1d age_w hatlev1d_w empat min_childage
   est1_1 est2_1 est3_1 est4_1 / CASES=FROM 1 TO 30.




*--- Graph: Predicted probability of employment patterns ---.

* for example Germany, the Netherlands and Slovenia.

* couples with at least one child <20, medium educated women.
TEMP.
SELECT IF min_childage<=15 AND hatlev1d_w=2 AND (country=7 OR country=23 OR country=29).
GRAPH
   /LINE(MULTIPLE)=MEAN(est1_1) MEAN(est2_1) MEAN(est3_1) MEAN(est4_1) BY min_childage
   /PANEL COLVAR=country ROWVAR=hatlev1d 
   /TITLE='predicted probability of employment patterns of couples by age of youngest child and country'
   /FOOTNOTE='medium educated women'.







